package uoc.integration;

import android.content.SharedPreferences;
import android.content.res.Resources;
import android.preference.PreferenceManager;
import android.support.test.espresso.ViewInteraction;
import android.support.test.rule.ActivityTestRule;

import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import uoc.testlink4android.MainActivity;
import uoc.testlink4android.R;

import static android.support.test.InstrumentationRegistry.getInstrumentation;
import static android.support.test.espresso.Espresso.onView;
import static android.support.test.espresso.action.ViewActions.click;
import static android.support.test.espresso.assertion.ViewAssertions.matches;
import static android.support.test.espresso.contrib.DrawerActions.open;
import static android.support.test.espresso.matcher.ViewMatchers.hasSibling;
import static android.support.test.espresso.matcher.ViewMatchers.isDisplayed;
import static android.support.test.espresso.matcher.ViewMatchers.withId;
import static android.support.test.espresso.matcher.ViewMatchers.withText;
import static org.hamcrest.Matchers.allOf;

public class TestSlideMenu {
    @Rule
    public ActivityTestRule<MainActivity> mActivityRule = new ActivityTestRule<>(
            MainActivity.class);
    public MainActivity mActivity = null;
    Resources resources = null;

    public TestSlideMenu() {
        this.resources = getInstrumentation().getTargetContext().getResources();
    }

    @Before
    public void setup() {
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getInstrumentation().getTargetContext());
        prefs.edit().clear();
        prefs.edit().commit(); // I am pretty sure this is not necessary but not harmful either.
    }

    @Test
    public void testOpenFilterProjects() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_filterProject))))).perform(click());
        ViewInteraction testPlan01_details = onView(withId(R.id.projectfilter));
        testPlan01_details.check(matches(isDisplayed()));
    }

    @Test
    public void testOpenTestPlans() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_testPlans))))).perform(click());

//        ViewInteraction testPlan01_details = onView(withId(R.id.testplanview));
//        testPlan01_details.check(matches(not(isDisplayed())));
    }

    @Test
    public void testOpenConfiguration() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_configuration))))).perform(click());

        ViewInteraction testPlan01_details = onView(withText(resources.getString(R.string.inline_preferences)));
        testPlan01_details.check(matches(isDisplayed()));
    }

    @Test
    public void testOpenPullData() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_pullData))))).perform(click());
    }

    @Test
    public void testOpenPushData() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_pushData))))).perform(click());
    }

    @Test
    public void testOpenClearData() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_clearData))))).perform(click());
    }

    @Test
    public void testExit() {
        onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText(resources.getString(R.string.slide_menu_exit))))).perform(click());
    }
}