package uoc.integration;

import android.content.Intent;
import android.content.SharedPreferences;
import android.content.res.Resources;
import android.preference.PreferenceManager;
import android.support.test.espresso.ViewInteraction;
import android.support.test.filters.LargeTest;
import android.support.test.rule.ActivityTestRule;
import android.support.test.runner.AndroidJUnit4;

import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Rule;
import org.junit.Test;
import org.junit.runner.RunWith;

import uoc.testlink4android.MainActivity;
import uoc.testlink4android.R;
import uoc.unit.TestCaseDaoTest;
import uoc.unit.TestPlanDaoTest;
import uoc.unit.TestProjectDaoTest;

import static android.support.test.InstrumentationRegistry.getInstrumentation;
import static android.support.test.espresso.Espresso.onView;
import static android.support.test.espresso.action.ViewActions.click;
import static android.support.test.espresso.assertion.ViewAssertions.matches;
import static android.support.test.espresso.contrib.DrawerActions.open;
import static android.support.test.espresso.matcher.ViewMatchers.hasSibling;
import static android.support.test.espresso.matcher.ViewMatchers.isDisplayed;
import static android.support.test.espresso.matcher.ViewMatchers.withId;
import static android.support.test.espresso.matcher.ViewMatchers.withText;
import static org.hamcrest.Matchers.allOf;
import static uoc.unit.SampleDataConstants.TEST_PLAN_01;
import static uoc.unit.SampleDataConstants.TEST_PLAN_02;


@RunWith(AndroidJUnit4.class)
@LargeTest
public class TestTestPlanView {
    @Rule
    public ActivityTestRule<MainActivity> mActivityRule = new ActivityTestRule<>(
            MainActivity.class);
    public MainActivity mActivity = null;
    Resources resources = null;
    TestSlideMenu testSlideMenu = null;


    public TestTestPlanView() {
        this.testSlideMenu = new TestSlideMenu();
        this.resources = getInstrumentation().getTargetContext().getResources();
    }

    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getInstrumentation().getTargetContext());
        prefs.edit().clear();
        prefs.edit().commit(); // I am pretty sure this is not necessary but not harmful either.

        try {
            TestProjectDaoTest testProjectDaoTest = new TestProjectDaoTest();
            testProjectDaoTest.setUp();
            testProjectDaoTest.testAddTestProjects();
            TestPlanDaoTest testPlanDaoTest = new TestPlanDaoTest();
            testPlanDaoTest.testAddTestPlans();
            TestCaseDaoTest testCaseDaoTest = new TestCaseDaoTest();
            testCaseDaoTest.testAddTestcases();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Before
    public void setup() {
        this.testSlideMenu = new TestSlideMenu();
    }

    @Test
    public void showTestplan01Details() {
        Intent intent = new Intent(Intent.ACTION_PICK);
        this.mActivity = mActivityRule.launchActivity(intent);
        // Type text and then press the button.
        ViewInteraction testplanList_testPlan01 = onView(withText(TEST_PLAN_01));
        testplanList_testPlan01.perform(click());

        ViewInteraction testPlan01_details = onView(withId(R.id.item_testplan_summary));
        testPlan01_details.check(matches(isDisplayed()));

        testSlideMenu.testOpenTestPlans();

        // Type text and then press the button.
        ViewInteraction testplanList_testPlan02 = onView(withText(TEST_PLAN_02));
        testplanList_testPlan02.perform(click());
    }

    @Test
    public void showTestplan02Details() {
        Intent intent = new Intent(Intent.ACTION_PICK);
        this.mActivity = mActivityRule.launchActivity(intent);
        // Type text and then press the button.
        ViewInteraction testplanList_testPlan01 = onView(withText(TEST_PLAN_01));
        testplanList_testPlan01.perform(click());

        ViewInteraction testPlan01_details = onView(withId(R.id.item_testplan_summary));
        testPlan01_details.check(matches(isDisplayed()));

        ViewInteraction slideMenu = onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText("Test plans")))).perform(click());

        // Type text and then press the button.
        ViewInteraction testplanList_testPlan02 = onView(withText(TEST_PLAN_02));
        testplanList_testPlan02.perform(click());
    }

    @Test
    public void showTestplan03Details() {
        Intent intent = new Intent(Intent.ACTION_PICK);
        this.mActivity = mActivityRule.launchActivity(intent);
        // Type text and then press the button.
        ViewInteraction testplanList_testPlan01 = onView(withText(TEST_PLAN_01));
        testplanList_testPlan01.perform(click());

        ViewInteraction testPlan01_details = onView(withId(R.id.item_testplan_summary));
        testPlan01_details.check(matches(isDisplayed()));

        ViewInteraction slideMenu = onView(withId(R.id.activity_main)).perform(open());
        onView(allOf(withId(R.id.item_title), hasSibling(withText("Test plans")))).perform(click());

        // Type text and then press the button.
        ViewInteraction testplanList_testPlan02 = onView(withText(TEST_PLAN_02));
        testplanList_testPlan02.perform(click());
    }

}
