package uoc.unit;

import android.content.Context;
import android.graphics.Color;
import android.support.test.InstrumentationRegistry;
import android.support.test.runner.AndroidJUnit4;
import android.util.Log;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.Database;
import uoc.testlink4android.db.schemas.IBuildSchema;
import uoc.testlink4android.db.schemas.ICustomFieldSchema;
import uoc.testlink4android.db.schemas.IPlatformSchema;
import uoc.testlink4android.db.schemas.ITestCaseSchema;
import uoc.testlink4android.db.schemas.ITestCaseStepSchema;
import uoc.testlink4android.db.schemas.ITestPlanSchema;
import uoc.testlink4android.db.schemas.ITestProjectSchema;
import uoc.testlink4android.db.schemas.IUserSchema;
import uoc.testlink4android.models.TestProject;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertNotNull;
import static junit.framework.Assert.assertTrue;

@RunWith(AndroidJUnit4.class)
public class TestProjectDaoTest {
    private Database databaseAccess;

    public TestProjectDaoTest() {
        super();
    }

    @Before
    public void setUp() throws Exception {
        Context instrumantationCtx = InstrumentationRegistry.getTargetContext();
        this.databaseAccess = Database.getInstance(instrumantationCtx);
        this.databaseAccess.clear();
        System.out.println(ITestProjectSchema.TESTPROYECT_TABLE_CREATE);
    }

    @After
    public void tearDown() throws Exception {
        databaseAccess.clear();
    }

    @Test
    public void testFetchTestProjectById() {
        TestProject testProject = new TestProject(1);
        testProject.setName("Proyecto");
        testProject.setNotes("Notas");
        testProject.setColor(Color.CYAN);
        testProject.setPrefix("PRJCT");
        testProject.setPublic(true);
        testProject.setActive(true);
        this.databaseAccess.mTestProjectDao.addTestProject(testProject);

        TestProject savedtestProject = this.databaseAccess.mTestProjectDao.fetchTestProjectById(1);

        assertNotNull(savedtestProject);
        assertEquals(savedtestProject.getName(), testProject.getName());
        assertEquals(savedtestProject.getNotes(), testProject.getNotes());
        assertEquals(savedtestProject.getPrefix(), testProject.getPrefix());
        assertEquals(savedtestProject.getColor(), testProject.getColor());
        assertEquals(savedtestProject.isActive(), testProject.isActive());
        assertEquals(savedtestProject.isPublic(), testProject.isPublic());
        Log.d("LOG0", ITestProjectSchema.TESTPROYECT_TABLE_CREATE);
        Log.d("LOG1", IBuildSchema.BUILD_TABLE_CREATE);
        Log.d("LOG2", ICustomFieldSchema.CUSTOMFIELD_TABLE_CREATE);
        Log.d("LOG3", IPlatformSchema.PLATFORM_TABLE_CREATE);
        Log.d("LOG4", ITestCaseStepSchema.TESTCASESTEP_TABLE_CREATE);
        Log.d("LOG5", ITestPlanSchema.TESTPLAN_TABLE_CREATE);
        Log.d("LOG6", ITestCaseStepSchema.TESTCASESTEP_TABLE_CREATE);
        Log.d("LOG7", IUserSchema.USER_TABLE_CREATE);
        Log.d("LOG8", ITestCaseSchema.TESTCASE_TABLE_CREATE);
    }

    @Test
    public void testFetchAllTestProjects() {
        TestProject testProject = new TestProject(1);
        testProject.setName("Proyecto");
        testProject.setNotes("Notas");
        this.databaseAccess.mTestProjectDao.addTestProject(testProject);

        TestProject savedtestProject = this.databaseAccess.mTestProjectDao.fetchTestProjectById(1);

        assertNotNull(savedtestProject);

    }

    public void testAddTestProject() {
        TestProject testProject = new TestProject(1);
        testProject.setName("Proyecto");
        testProject.setNotes("Notas");
        this.databaseAccess.mTestProjectDao.addTestProject(testProject);

        TestProject savedtestProject = this.databaseAccess.mTestProjectDao.fetchTestProjectById(1);
        assertEquals(savedtestProject.getName(), testProject.getName());
//        assertThat(savedtestProject.getId(), is(1));

        assertNotNull(savedtestProject);

    }

    @Test
    public void testAddTestProjects() {
        TestProject tp01 = new TestProject(1, SampleDataConstants.PROYECTO_01, "PRYCT01", "notas01", false,
                false, false, true, true, true, Color.GREEN);

        TestProject tp02 = new TestProject(2, SampleDataConstants.PROYECTO_02, "PRYCT02", "notas02", true,
                false, false, true, true, false, Color.BLUE);

        TestProject tp03 = new TestProject(3, SampleDataConstants.PROYECTO_03, "PRYCT03", "notas03", false,
                true, false, true, true, true, Color.CYAN);

        List<TestProject> projects = new ArrayList<>(3);
        projects.add(tp01);
        projects.add(tp02);
        projects.add(tp03);

        this.databaseAccess.mTestProjectDao.addTestProjects(projects);

        List<TestProject> savedtestProjects = this.databaseAccess.mTestProjectDao.fetchAllTestProjects();

        assertEquals(savedtestProjects.size(), projects.size());

        int index = 0;
        for (TestProject savedtestProject : savedtestProjects) {
            assertEquals(savedtestProject, projects.get(index));
            index++;
        }
    }

    @Test
    public void testDeleteAllTestProjects() {
        List<TestProject> savedtestProjects = this.databaseAccess.mTestProjectDao.fetchAllTestProjects();
        assertTrue(savedtestProjects.size() == 0);
        testAddTestProjects();
        savedtestProjects = this.databaseAccess.mTestProjectDao.fetchAllTestProjects();
        assertTrue(savedtestProjects.size() > 0);
        savedtestProjects = this.databaseAccess.mTestProjectDao.fetchAllTestProjects();
        this.databaseAccess.mTestProjectDao.deleteAllTestProjects();
        savedtestProjects = this.databaseAccess.mTestProjectDao.fetchAllTestProjects();
        assertTrue(savedtestProjects.size() == 0);
    }
}