package uoc.testlink4android;

import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.design.widget.Snackbar;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.background.AsyncRefreshUI;
import uoc.testlink4android.background.AsyncResponse;
import uoc.testlink4android.background.PullTestlinkData;
import uoc.testlink4android.background.PushTestlinkData;
import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.ui.ItemSlideMenu;
import uoc.testlink4android.ui.adapter.SlidingMenuAdapter;
import uoc.testlink4android.ui.fragment.PreferencesView;
import uoc.testlink4android.ui.fragment.ProjectFilterView;
import uoc.testlink4android.ui.fragment.TestPlanList;
import uoc.testlink4android.util.Constantes;

import static uoc.testlink4android.util.Constantes.SELECTED_PROJECTS;

public class MainActivity extends AppCompatActivity implements AsyncResponse {
    private List<ItemSlideMenu> listSliding;
    private SlidingMenuAdapter adapter;
    private ListView listViewSliding;
    private DrawerLayout drawerLayout;
    private ActionBarDrawerToggle actionBarDrawerToggle;
    private Fragment currentDisplayedFragment;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        initialize();
    }

    private void initialize() {
        //Init component
        listViewSliding = (ListView) findViewById(R.id.sliding_menu);
        drawerLayout = (DrawerLayout) findViewById(R.id.activity_main);
        listSliding = new ArrayList<>(8);
        //Add item for sliding list
        listSliding.add(new ItemSlideMenu(R.drawable.ic_view_headline_black_24dp, getString(R.string.slide_menu_filterProject)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_view_module_black_24dp, getString(R.string.slide_menu_testPlans)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_action_settings, getString(R.string.slide_menu_configuration)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_system_update_alt_black_24dp, getString(R.string.slide_menu_pullData)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_push_alt_black_24dp, getString(R.string.slide_menu_pushData)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_clear_black_24dp, getString(R.string.slide_menu_clearData)));
        listSliding.add(new ItemSlideMenu(R.drawable.ic_exit_to_app_black_24dp, getString(R.string.slide_menu_exit)));
        adapter = new SlidingMenuAdapter(this, listSliding);
        listViewSliding.setAdapter(adapter);

        //Display icon to open/ close sliding list
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        //Set title
        setTitle(listSliding.get(1).getTitle());
        //item selected
        listViewSliding.setItemChecked(1, true);
        //Close menu
        drawerLayout.closeDrawer(listViewSliding);

        //Display fragment 1 when start
//        replaceFragment(1);
        //Hanlde on item click

        listViewSliding.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                //Set title
                if (position == 0 || position == 1 || position == 2) { // NO TITLE CHANGE FOR THE OTHERS
                    setTitle(listSliding.get(position).getTitle());
                }
                //item selected
                listViewSliding.setItemChecked(position, true);
                //Replace fragment
                if (position == 0 || position == 1 || position == 2) {
                    replaceFragment(position);
                } else {
                    handleSlideMenuAction(position);
                }

                //Close menu
                drawerLayout.closeDrawer(listViewSliding);
            }
        });

        actionBarDrawerToggle = new ActionBarDrawerToggle(this, drawerLayout, R.string.drawer_opened, R.string.drawer_closed) {

            @Override
            public void onDrawerOpened(View drawerView) {
                super.onDrawerOpened(drawerView);
                invalidateOptionsMenu();
            }

            @Override
            public void onDrawerClosed(View drawerView) {
                super.onDrawerClosed(drawerView);
                invalidateOptionsMenu();
            }
        };

        drawerLayout.setDrawerListener(actionBarDrawerToggle);

    }

    @Override
    public void processFinish(String output) {
        if (output != null && getCurrentFocus() != null) {
            Snackbar.make(getCurrentFocus(), output, Snackbar.LENGTH_LONG)
                    .setAction("Action", null).show();

        }
        if (currentDisplayedFragment != null) {
            if (currentDisplayedFragment instanceof AsyncRefreshUI) {
                ((AsyncRefreshUI) currentDisplayedFragment).refresh();
            }
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.main_menu, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (actionBarDrawerToggle.onOptionsItemSelected(item)) {
            return true;
        } else {
            switch (item.getItemId()) {
                case R.id.move_to_testplan_view:
                    replaceFragment(1);
                    setTitle(listSliding.get(1).getTitle());
                    return true;
                default:
                    return super.onOptionsItemSelected(item);
            }
        }
    }

    @Override
    protected void onPostCreate(Bundle savedInstanceState) {
        super.onPostCreate(savedInstanceState);
        actionBarDrawerToggle.syncState();
        replaceFragment(1);
    }

    private void clearDBAndPreferences() {
        try {
            Database.getInstance(getApplicationContext()).clear();
            SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getApplicationContext());
            SharedPreferences.Editor edit = prefs.edit().remove(SELECTED_PROJECTS);
            if (edit != null) edit.commit();
            if (currentDisplayedFragment instanceof AsyncRefreshUI) {
                ((AsyncRefreshUI) currentDisplayedFragment).refresh();
            }
        } catch (Exception ex) {
            Snackbar.make(getCurrentFocus(), "Error clearing DB content!", Snackbar.LENGTH_LONG)
                    .setAction("Action", null).show();
        }
    }

    private void pullTestlinkDataPopulateDB() {
        try {
            Database.getInstance(getApplicationContext()).clear();
            PullTestlinkData.getInstance(this, getApplicationContext()).execute((URL) null);
        } catch (Exception ex) {
            Snackbar.make(getCurrentFocus(), "Error accessing testlink server!", Snackbar.LENGTH_LONG)
                    .setAction("Action", null).show();
        }
    }

    private void handleSlideMenuAction(int pos) {
        switch (pos) {
            case 3:
                pullTestlinkDataPopulateDB();
                break;
            case 4:
                PushTestlinkData.getInstance(this, getApplicationContext()).execute((URL) null);
                break;
            case 5:
                clearDBAndPreferences();
                break;
            case 6:
                finish();
                break;
        }
    }

    private void replaceFragment(int pos) {
        Fragment fragment = getFragmentManager().findFragmentByTag(Constantes.FRAGMENT.values()[pos].name());
        boolean addToStack = false;
        Constantes.FRAGMENT tag = Constantes.FRAGMENT. PLACEHOLDER_FRAGMENT;
        if (fragment == null) {
            addToStack = true;
            switch (pos) {
                case 0:
                    fragment = new ProjectFilterView();
                    tag = Constantes.FRAGMENT.PROJECT_FRAGMENT;
                    break;
                case 1:
                    fragment = new TestPlanList();
                    tag = Constantes.FRAGMENT.TEST_PLAN_FRAGMENT;
                    break;
                case 2:
                    fragment = new PreferencesView();
                    tag = Constantes.FRAGMENT.PREFERENCES_FRAGMENT;
                    break;
                default:
                    fragment = new TestPlanList();
                    tag = Constantes.FRAGMENT.TEST_PLAN_FRAGMENT;
                    break;
            }
        }

        if(currentDisplayedFragment != null &&  !currentDisplayedFragment.isVisible()){
            currentDisplayedFragment = getFragmentManager().findFragmentByTag(Constantes.FRAGMENT.SELECTBUILD_FRAGMENT.name());
        }

        if (fragment != currentDisplayedFragment ) {
            FragmentTransaction ft = getFragmentManager().beginTransaction();
            if (addToStack) {
                if (currentDisplayedFragment == null) {
                    ft.add(R.id.main_content, fragment,tag.name());
                } else {
                    ft.detach(currentDisplayedFragment);
                    ft.add(R.id.main_content, fragment, tag.name());
                }
            } else {
                ft.detach(currentDisplayedFragment);
                ft.attach(fragment);
            }
            ft.commit();
            this.currentDisplayedFragment = fragment;
        }
    }
}
