package uoc.testlink4android.background;


import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.preference.PreferenceManager;
import android.util.Log;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.Build;
import uoc.testlink4android.models.TestCase;
import uoc.testlink4android.models.TestPlan;
import uoc.testlink4android.models.TestProject;
import uoc.testlink4android.testlink.javaapi.TestLinkAPI;
import uoc.testlink4android.util.Utilities;

import static android.support.test.InstrumentationRegistry.getContext;
import static uoc.testlink4android.util.Constantes.SELECTED_PROJECTS;

public class PullTestlinkData extends android.os.AsyncTask<java.net.URL, java.lang.Integer, java.lang.String> {
    public AsyncResponse delegate = null;
    private TestLinkAPI testLinkAPI;
    private Context context;

    private PullTestlinkData(AsyncResponse delegate, Context context) {
        super();
        this.delegate = delegate;
        this.context = context;
    }

    public static PullTestlinkData getInstance(AsyncResponse delegate, Context context) {
        return new PullTestlinkData(delegate, context);
    }

    private TestLinkAPI getServerConnection() throws MalformedURLException {
        TestLinkAPI testLinkAPI = null;
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
        String serverURL = prefs.getString("server_URL", "http://192.168.1.44/testlink/lib/api/xmlrpc/v1/xmlrpc.php");
        String userKey = prefs.getString("user_key", "82aef4843220dfaea7417eebbb7a089a");
        Log.d("serverURL", serverURL);
        Log.d("userKey", userKey);
        testLinkAPI = new TestLinkAPI(new URL(serverURL), userKey);
        return testLinkAPI;
    }

    @Override
    protected String doInBackground(URL... urls) {
        String result = null;
        try {
            this.testLinkAPI = getServerConnection();
            if (this.testLinkAPI != null) {
                Database databaseAccess = Database.getInstance(context);
                TestProject[] testProjects = this.testLinkAPI.getProjects();
                String[] projectColors = Utilities.getProjectColors(context);
                TestProject testProject = null;
                for (int i = 0; i < testProjects.length; i++) {
                    testProject = testProjects[i];
                    testProject.setColor(Color.parseColor(projectColors[i]));
                    TestPlan[] testPlans = this.testLinkAPI.getProjectTestPlans(testProject.getId());
                    for (TestPlan testPlan : testPlans) {
                        testPlan.setProjectId(testProject.getId());
                        testPlan.setProjectName(testProject.getName());
//                    Map<String,Object> testPlanss = this.testLinkAPI.getTotalsForTestPlan(testPlan.getId());
//                    Platform[] testPlansss = this.testLinkAPI.getTestPlanPlatforms(testPlan.getId());
//                    Platform[] testPlansss = this.testLinkAPI.getTestPlanPlatforms(testPlan.getId());

                        Build[] builds = this.testLinkAPI.getBuildsForTestPlan(testPlan.getId());
                        if (builds != null) {
                            databaseAccess.mBuilDao.addBuilds(Arrays.asList(builds));
                        }

                        TestCase[] testCases = this.testLinkAPI.getTestCasesForTestPlan(testPlan.getId(), null, null, null, null, null, null, null, null, true, null);
                        if (testCases != null) {
                            TestCase tc = null;
                            for (TestCase testCase : testCases) {
                                tc = this.testLinkAPI.getTestCase(testCase.getId(), null, null);

                                tc.setTestPlanId(testPlan.getId());
                                databaseAccess.mTestCaseDao.addTestCase(tc, testPlan.getId());
                            }
                        }
                    }
                    databaseAccess.mTestPlanDao.addTestPlans(Arrays.asList(testPlans));
                }
                databaseAccess.mTestProjectDao.addTestProjects(Arrays.asList(testProjects));
                initPreferences(testProjects);
            }
        } catch (MalformedURLException ex) {
            result = "The URL provided to access testlink server is incorrect";
        } catch (Exception ex) {
            Log.d("XMLRPC01", "", ex);
            result = ex.getMessage();
        }
        return result;
    }

    protected void onProgressUpdate(Integer... progress) {
    }

    private void initPreferences(TestProject[] testProjects){
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
        Set<String> selectedProjects = new HashSet<String>(testProjects.length);
        for(TestProject testProject:testProjects){
            selectedProjects.add(Integer.toString(testProject.getId()));
        }
        prefs.edit().putStringSet(SELECTED_PROJECTS, selectedProjects).commit();
    }

    @Override
    public void onPostExecute(String result) {
        delegate.processFinish(result);
    }
}
