package uoc.testlink4android.db;

import android.content.Context;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import uoc.testlink4android.db.daos.BuildDao;
import uoc.testlink4android.db.daos.ExecutionDao;
import uoc.testlink4android.db.daos.TestCaseDao;
import uoc.testlink4android.db.daos.TestPlanDao;
import uoc.testlink4android.db.daos.TestProjectDao;
import uoc.testlink4android.db.daos.UserDao;
import uoc.testlink4android.db.schemas.IBuildSchema;
import uoc.testlink4android.db.schemas.ICustomFieldSchema;
import uoc.testlink4android.db.schemas.IExecutionSchema;
import uoc.testlink4android.db.schemas.IPlatformSchema;
import uoc.testlink4android.db.schemas.ITestCaseSchema;
import uoc.testlink4android.db.schemas.ITestCaseStepSchema;
import uoc.testlink4android.db.schemas.ITestPlanSchema;
import uoc.testlink4android.db.schemas.ITestProjectSchema;
import uoc.testlink4android.db.schemas.IUserSchema;

public class Database {
    private static final String TAG = "Testlink";
    private static final String DATABASE_NAME = "Testlink.db";
    // Increment DB Version on any schema change
    private static final int DATABASE_VERSION = 1;
    public static TestCaseDao mTestCaseDao;
    public static UserDao mUserDao;
    public static TestPlanDao mTestPlanDao;
    public static TestProjectDao mTestProjectDao;
    public static BuildDao mBuilDao;
    public static ExecutionDao mExecutionDao;
    private static Database INSTANCE;
    private DatabaseHelper mDbHelper;

    private Database() {
    }

    public static Database getInstance(Context applicationContext) {
        if (INSTANCE == null) {
            INSTANCE = new Database();
            INSTANCE.open(applicationContext);
        }
        return INSTANCE;
    }

    private Database open(Context applicationContext) throws SQLException {
        mDbHelper = new DatabaseHelper(applicationContext);
        SQLiteDatabase mDb = mDbHelper.getWritableDatabase();
        mUserDao = new UserDao(mDb);
        mTestPlanDao = new TestPlanDao(mDb);
        mTestProjectDao = new TestProjectDao(mDb);
        mBuilDao = new BuildDao(mDb);
        mTestCaseDao = new TestCaseDao(mDb);
        mExecutionDao = new ExecutionDao(mDb);
//        mDbHelper.onUpgrade(mDb,1,2);
        return this;
    }

    public void clear() throws SQLException {
        SQLiteDatabase mDb = mDbHelper.getWritableDatabase();
        mDbHelper.onUpgrade(mDb, 1, 2);
    }

    public void close() {
        mDbHelper.close();
    }

    private static class DatabaseHelper extends SQLiteOpenHelper {
        DatabaseHelper(Context context) {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {
            db.execSQL(ITestPlanSchema.TESTPLAN_TABLE_CREATE);
            db.execSQL(IUserSchema.USER_TABLE_CREATE);
            db.execSQL(ITestProjectSchema.TESTPROYECT_TABLE_CREATE);
            db.execSQL(IBuildSchema.BUILD_TABLE_CREATE);
            db.execSQL(ITestCaseSchema.TESTCASE_TABLE_CREATE);
            db.execSQL(ITestCaseStepSchema.TESTCASESTEP_TABLE_CREATE);
            db.execSQL(ICustomFieldSchema.CUSTOMFIELD_TABLE_CREATE);
            db.execSQL(IPlatformSchema.PLATFORM_TABLE_CREATE);
            db.execSQL(IExecutionSchema.EXECUTION_TABLE_CREATE);
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion,
                              int newVersion) {
            Log.w(TAG, "Upgrading database from version "
                    + oldVersion + " to "
                    + newVersion + " which destroys all old data");

            db.execSQL("DROP TABLE IF EXISTS "
                    + ITestPlanSchema.TESTPLAN_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + IUserSchema.USER_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + ITestProjectSchema.TESTPROJECT_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + IBuildSchema.BUILD_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + ITestCaseSchema.TESTCASE_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + ITestCaseStepSchema.TESTCASESTEP_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + ICustomFieldSchema.CUSTOMFIELD_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + IPlatformSchema.PLATFORM_TABLE);
            db.execSQL("DROP TABLE IF EXISTS "
                    + IExecutionSchema.EXECUTION_TABLE);
            onCreate(db);
        }
    }
}