package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.IBuildSchema;
import uoc.testlink4android.models.Build;


public class BuildDao extends DbContentProvider implements IBuildDao, IBuildSchema {
    private Cursor cursor;
    private ContentValues initialValues;

    public BuildDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected Build cursorToEntity(Cursor cursor) {
        Build build = null;

        int idIndex;
        int nameIndex;
        int testplanIDIndex;
        int notesIndex;

        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                idIndex = cursor.getColumnIndexOrThrow(COLUMN_ID);
                build = new Build(cursor.getInt(idIndex));
            }
            if (cursor.getColumnIndex(COLUMN_NAME) != -1) {
                nameIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_NAME);
                build.setName(cursor.getString(nameIndex));
            }
            if (cursor.getColumnIndex(COLUMN_TESTPLAN_ID) != -1) {
                testplanIDIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_TESTPLAN_ID);
                build.setTestPlanId(cursor.getInt(testplanIDIndex));
            }
            if (cursor.getColumnIndex(COLUMN_NOTES) != -1) {
                notesIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_NOTES);
                build.setNotes(cursor.getString(notesIndex));
            }

        }
        return build;
    }

    @Override
    public Build fetchBuildById(int buildId) {
        return null;
    }

    @Override
    public List<Build> fetchAllBuilds() {
        List<Build> builds = new ArrayList<Build>();
        cursor = super.query(BUILD_TABLE, BUILD_COLUMNS, null,
                null, COLUMN_ID);

        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                Build build = cursorToEntity(cursor);
                builds.add(build);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return builds;
    }

    @Override
    public List<Build> fetchTestplanBuilds(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId)};
        final String selection = COLUMN_TESTPLAN_ID + " = ?";
        List<Build> builds = new ArrayList<Build>();
        cursor = super.query(BUILD_TABLE, BUILD_COLUMNS, selection,
                selectionArgs, COLUMN_ID);

        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                Build build = cursorToEntity(cursor);
                builds.add(build);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return builds;
    }

    @Override
    public boolean addBuild(Build build) {
        // set values
        setContentValue(build);
        try {
            return super.insert(BUILD_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    @Override
    public boolean addBuilds(List<Build> builds) {
        // set values
        try {
            for (Build testPlan : builds) {
                setContentValue(testPlan);
                if (!(super.insert(BUILD_TABLE, getContentValue()) > 0)) {
                    return false;
                }
            }
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
        return true;
    }

    @Override
    public boolean deleteAllBuilds() {
        return false;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(Build testProject) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, testProject.getId());
        initialValues.put(COLUMN_NAME, testProject.getName());
        initialValues.put(COLUMN_NOTES, testProject.getNotes());
        initialValues.put(COLUMN_TESTPLAN_ID, testProject.getTestPlanId());
    }

}
