package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.ICustomFieldSchema;
import uoc.testlink4android.models.CustomField;

public class CustomFieldDao extends DbContentProvider
        implements ICustomFieldSchema, ICustomFieldDao {
    private Cursor cursor;
    private ContentValues initialValues;

    public CustomFieldDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected CustomField cursorToEntity(Cursor cursor) {
        CustomField customField = null;
        int index = 0;
        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_ID);
                customField = new CustomField(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_NAME);
                customField.setName(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_LABEL) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_LABEL);
                customField.setLabel(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_TYPE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TYPE);
                customField.setType(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_POSSIBLE_VALUES) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_POSSIBLE_VALUES);
                customField.setPossibleValues(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_DEFAULT_VALUE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_DEFAULT_VALUE);
                customField.setDefaultValue(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_VALID_REGEXP) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_VALID_REGEXP);
                customField.setValidRegexp(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_LENGTH_MIN) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_LENGTH_MIN);
                customField.setLengthMin(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_LENGTH_MAX) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_LENGTH_MAX);
                customField.setLengthMax(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_SHOW_ON_DESIGN) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_SHOW_ON_DESIGN);
                customField.setShowOnDesign(Boolean.parseBoolean(cursor.getString(index)));
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_ON_EXECUTION) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_ON_EXECUTION);
                customField.setEnableOnExecution(Boolean.parseBoolean(cursor.getString(index)));
            }
            if (cursor.getColumnIndex(COLUMN_SHOW_ON_TEST_PLAN_DESIGN) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_SHOW_ON_TEST_PLAN_DESIGN);
                customField.setShowOnTestPlanDesign(Boolean.parseBoolean(cursor.getString(index)));
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_ON_TEST_PLAN_DESIGN) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_ON_TEST_PLAN_DESIGN);
                customField.setEnableOnTestPlanDesign(Boolean.parseBoolean(cursor.getString(index)));
            }
            if (cursor.getColumnIndex(COLUMN_DISPLAY_ORDER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_DISPLAY_ORDER);
                customField.setDisplayOrder(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_LOCATION) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_LOCATION);
                customField.setLocation(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_VALUE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_VALUE);
                customField.setValue(cursor.getString(index));
            }
        }
        return customField;
    }

    @Override
    public CustomField fetchCustomFieldById(int customFieldId) {
        return null;
    }

    @Override
    public List<CustomField> fetchAllCustomFields() {
        return null;
    }

    @Override
    public boolean addCustomField(CustomField customField, int testCaseId) {
        // set values
        setContentValue(customField, testCaseId);
        try {
            return super.insert(CUSTOMFIELD_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(CustomField customField, int testCaseId) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, customField.getId());
        initialValues.put(COLUMN_NAME, customField.getName());
        initialValues.put(COLUMN_LABEL, customField.getLabel());
        initialValues.put(COLUMN_TYPE, customField.getType());
        initialValues.put(COLUMN_POSSIBLE_VALUES, customField.getPossibleValues());
        initialValues.put(COLUMN_DEFAULT_VALUE, customField.getDefaultValue());
        initialValues.put(COLUMN_VALID_REGEXP, customField.getValidRegexp());
        initialValues.put(COLUMN_LENGTH_MIN, customField.getLengthMin());
        initialValues.put(COLUMN_LENGTH_MAX, customField.getLengthMax());
        initialValues.put(COLUMN_SHOW_ON_DESIGN, customField.getShowOnDesign());
        initialValues.put(COLUMN_ENABLE_ON_EXECUTION, customField.getEnableOnExecution());
        initialValues.put(COLUMN_SHOW_ON_TEST_PLAN_DESIGN, customField.getShowOnTestPlanDesign());
        initialValues.put(COLUMN_ENABLE_ON_TEST_PLAN_DESIGN, customField.isEnableOnTestPlanDesign());
        initialValues.put(COLUMN_DISPLAY_ORDER, customField.getDisplayOrder());
        initialValues.put(COLUMN_LOCATION, customField.getLocation());
        initialValues.put(COLUMN_VALUE, customField.getValue());
        initialValues.put(COLUMN_TEST_CASE_ID, testCaseId);
    }

    @Override
    public boolean addCustomFields(List<CustomField> customFields, int testCaseId) {
        boolean result = true;
        for (CustomField customField : customFields) {
            if (!addCustomField(customField, testCaseId)) {
                result = false;
            }
        }
        return result;
    }

    @Override
    public boolean deleteAllCustomFields() {
        return false;
    }

    @Override
    public List<CustomField> fetchAllCustomFieldsByTestCaseId(int testCaseId) {
        final String selectionArgs[] = {String.valueOf(testCaseId)};
        final String selection = COLUMN_TEST_CASE_ID + " = ?";
        cursor = super.query(CUSTOMFIELD_TABLE, CUSTOMFIELD_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        List<CustomField> customFields = new ArrayList<CustomField>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                CustomField customField = cursorToEntity(cursor);
                customFields.add(customField);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return customFields;
    }
}
