package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.IExecutionSchema;
import uoc.testlink4android.models.Execution;
import uoc.testlink4android.testlink.constants.ExecutionStatus;
import uoc.testlink4android.testlink.constants.ExecutionType;

public class ExecutionDao extends DbContentProvider
        implements IExecutionSchema, IExecutionDao {
    private Cursor cursor;
    private ContentValues initialValues;

    public ExecutionDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected Execution cursorToEntity(Cursor cursor) {
        Execution execution = null;
        int index = 0;
        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_ID);
                execution = new Execution(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_BUILD_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_BUILD_ID);
                execution.setBuildId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_ID);
                execution.setTestCaseId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TESTER_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TESTER_ID);
                execution.setTesterId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_TIME_STAMP) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_TIME_STAMP);
                int timestamp = cursor.getInt(index);
                execution.setExecutionTimeStamp(new Date(timestamp * 1000L));
            }
            if (cursor.getColumnIndex(COLUMN_STATUS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_STATUS);

                String executionStatus = cursor.getString(index);
                char execStat = executionStatus.length() > 0 ? executionStatus.charAt(0) : ExecutionStatus.NOT_RUN.getValue();
                ExecutionStatus execStatus = ExecutionStatus.getExecutionStatus(execStat);
                execution.setStatus(execStatus);
            }
            if (cursor.getColumnIndex(COLUMN_TEST_PLAN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_PLAN_ID);
                execution.setTestPlanId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_VERSION_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_VERSION_ID);
                execution.setTestCaseVersionId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_VERSION_NUMBER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_VERSION_NUMBER);
                execution.setTestCaseVersionNumber(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_TYPE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_TYPE);
                ExecutionType executionType = ExecutionType.getExecutionType(cursor.getInt(index));
                execution.setExecutionType(executionType);
            }
            if (cursor.getColumnIndex(COLUMN_NOTES) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_NOTES);
                execution.setNotes(cursor.getString(index));
            }
        }
        return execution;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(Execution execution, int testCaseId) {
        initialValues = new ContentValues();
//        initialValues.put(COLUMN_ID, execution.getId());
        initialValues.put(COLUMN_TEST_CASE_ID, execution.getTestCaseId());
        initialValues.put(COLUMN_BUILD_ID, execution.getBuildId());
        initialValues.put(COLUMN_TESTER_ID, execution.getTesterId());
        initialValues.put(COLUMN_EXECUTION_TIME_STAMP, execution.getExecutionTimeStamp().getTime() / 1000L);
        initialValues.put(COLUMN_STATUS, execution.getStatus() == null ? null : execution.getStatus().toString());
        initialValues.put(COLUMN_TEST_PLAN_ID, execution.getTestPlanId());
        initialValues.put(COLUMN_TEST_CASE_VERSION_ID, execution.getTestCaseVersionId());
        initialValues.put(COLUMN_TEST_CASE_VERSION_NUMBER, execution.getTestCaseVersionNumber());
        initialValues.put(COLUMN_EXECUTION_TYPE, execution.getExecutionType() == null ? null : execution.getExecutionType().toString());
        initialValues.put(COLUMN_NOTES, execution.getNotes());
    }

    @Override
    public Execution fetchExecutionById(int executionId) {
        final String selectionArgs[] = {String.valueOf(executionId)};
        final String selection = " = ?";
        Execution execution = new Execution(executionId);
        cursor = super.query(IExecutionSchema.EXECUTION_TABLE, IExecutionSchema.EXECUTION_COLUMNS, selection,
                selectionArgs, IExecutionSchema.COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                execution = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return execution;
    }

    @Override
    public List<Execution> fetchExecutionsByTesCaseId(int testCaseId) {
        final String selectionArgs[] = {String.valueOf(testCaseId)};
        final String selection = COLUMN_TEST_CASE_ID + " = ?";
        cursor = super.query(IExecutionSchema.EXECUTION_TABLE, IExecutionSchema.EXECUTION_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        List<Execution> executions = new ArrayList<Execution>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                Execution execution = cursorToEntity(cursor);
                executions.add(execution);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return executions;
    }

    @Override
    public List<Execution> fetchExecutions(int testPlanId, int buildId) {
        final String selectionArgs[] = {String.valueOf(testPlanId), String.valueOf(buildId)};
        final String selection = COLUMN_TEST_PLAN_ID + " = ? AND " + COLUMN_BUILD_ID + " = ?";
        cursor = super.query(IExecutionSchema.EXECUTION_TABLE, IExecutionSchema.EXECUTION_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        List<Execution> executions = new ArrayList<Execution>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                Execution execution = cursorToEntity(cursor);
                executions.add(execution);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return executions;
    }

    @Override
    public boolean addExecution(Execution execution, Integer executionId) {
        // set values
        setContentValue(execution, executionId);
        try {
            return super.insert(EXECUTION_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    @Override
    public boolean deleteExecutions() {
        return false;
    }
}
