package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.IPlatformSchema;
import uoc.testlink4android.models.Platform;

public class PlatformDao extends DbContentProvider
        implements IPlatformSchema, IPlatformDao {
    private Cursor cursor;
    private ContentValues initialValues;

    public PlatformDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected Platform cursorToEntity(Cursor cursor) {
        Platform platform = null;

        int idIndex;
        int platformName;
        int platformNotes;

        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                idIndex = cursor.getColumnIndexOrThrow(COLUMN_ID);
                platform = new Platform(cursor.getInt(idIndex));
            }
            if (cursor.getColumnIndex(COLUMN_NAME) != -1) {
                platformName = cursor.getColumnIndexOrThrow(
                        COLUMN_NAME);
                platform.setName(cursor.getString(platformName));
            }
            if (cursor.getColumnIndex(COLUMN_NOTES) != -1) {
                platformNotes = cursor.getColumnIndexOrThrow(
                        COLUMN_NOTES);
                platform.setNotes(cursor.getString(platformNotes));
            }
        }
        return platform;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(Platform platform) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, platform.getId());
        initialValues.put(COLUMN_NAME, platform.getName());
        initialValues.put(COLUMN_NOTES, platform.getName());
    }

//    @Override
//    public boolean addPlatforms(List<Platform> platforms, int testCaseId) {
//        boolean result = true;
//        for (Platform platform : platforms) {
//            if (!addPlatform(platform)) {
//                result = false;
//            }
//        }
//        return result;
//    }

    @Override
    public boolean deleteAllPlatforms() {
        return false;
    }

    @Override
    public Platform fetchPlatformByPlatformId(int platformId) {
        final String selectionArgs[] = {String.valueOf(platformId)};
        final String selection = COLUMN_ID + " = ?";
        cursor = super.query(PLATFORM_TABLE, PLATFORM_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        Platform platform = null;
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                platform = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return platform;
    }

    @Override
    public boolean addPlatform(Platform platform) {
        // set values
        setContentValue(platform);
        try {
            return super.insert(PLATFORM_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }
}