package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.ITestCaseSchema;
import uoc.testlink4android.models.CustomField;
import uoc.testlink4android.models.Platform;
import uoc.testlink4android.models.TestCase;
import uoc.testlink4android.models.TestCaseStep;
import uoc.testlink4android.testlink.constants.ActionOnDuplicate;
import uoc.testlink4android.testlink.constants.ExecutionStatus;
import uoc.testlink4android.testlink.constants.ExecutionType;
import uoc.testlink4android.testlink.constants.TestCaseStatus;
import uoc.testlink4android.testlink.constants.TestImportance;

public class TestCaseDao extends DbContentProvider
        implements ITestCaseSchema, ITestCaseDao {
    private static String STRING_SEPARATOR = "__,__";
    // METHODS USED TO PARSE KEY WORDS FIELD
    private TestCaseStepDao testCaseStepDao;
    private CustomFieldDao customFieldDao;
    private PlatformDao platformDao;
    private Cursor cursor;
    private ContentValues initialValues;

    public TestCaseDao(SQLiteDatabase db) {
        super(db);
        this.testCaseStepDao = new TestCaseStepDao(db);
        this.customFieldDao = new CustomFieldDao(db);
        this.platformDao = new PlatformDao(db);
    }

    public static String convertArrayToString(String[] array) {
        String str = "";
        for (int i = 0; i < array.length; i++) {
            str = str + array[i];
            // Do not append comma at the end of last element
            if (i < array.length - 1) {
                str = str + STRING_SEPARATOR;
            }
        }
        return str;
    }

    public static String[] convertStringToArray(String str) {
        String[] arr = str.split(STRING_SEPARATOR);
        return arr;
    }

    protected TestCase cursorToEntity(Cursor cursor) {
        TestCase testCase = null;

        int index = 0;

        if (cursor != null) {
            if (cursor.getColumnIndex(ITestCaseSchema.COLUMN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(ITestCaseSchema.COLUMN_ID);
                testCase = new TestCase(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_NAME);
                testCase.setName(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_PROJECT_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_PROJECT_ID);
                testCase.setTestProjectId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_SUITE_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_SUITE_ID);
                testCase.setTestSuiteId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_AUTHOR_LOGIN) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_AUTHOR_LOGIN);
                testCase.setAuthorLogin(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_SUMMARY) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_SUMMARY);
                testCase.setSummary(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_PRECONDITIONS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_PRECONDITIONS);
                testCase.setPreconditions(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_STATUS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_STATUS);
                Integer testCaseStatus = cursor.getInt(index);
                testCase.setTestCaseStatus(TestCaseStatus.getTestCaseStatus(testCaseStatus));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_IMPORTANCE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_IMPORTANCE);
                testCase.setTestImportance(TestImportance.parseTestImportance(cursor.getInt(index)));
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_TYPE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_TYPE);
                ExecutionType executionType = ExecutionType.getExecutionType(cursor.getInt(index));
                testCase.setExecutionType(executionType);
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_ORDER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_ORDER);
                testCase.setExecutionOrder(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_ORDER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ORDER);
                testCase.setOrder(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_INTERNAL_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_INTERNAL_ID);
                testCase.setInternalId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_FULL_EXTERNAL_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_FULL_EXTERNAL_ID);
                testCase.setFullExternalId(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_CHECK_DUPLICATED_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_CHECK_DUPLICATED_NAME);
                testCase.setCheckDuplicatedName(cursor.getInt(index) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_ACTION_ON_DUPLATED_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ACTION_ON_DUPLATED_NAME);
                testCase.setActionOnDuplicatedName(ActionOnDuplicate.getActionOnDuplicate(cursor.getString(index)));
            }
            if (cursor.getColumnIndex(COLUMN_VERSION_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_VERSION_ID);
                testCase.setVersionId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_VERSION) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_VERSION);
                testCase.setVersion(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_PARENT_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_PARENT_ID);
                testCase.setParentId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_PLATFORM) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_PLATFORM);
                testCase.setPlatform(new Platform(cursor.getInt(index)));
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_STATUS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_STATUS);
                String executionStatus = cursor.getString(index);
                char execStat = executionStatus.length() > 0 ? executionStatus.charAt(0) : ExecutionStatus.NOT_RUN.getValue();
                ExecutionStatus execStatus = ExecutionStatus.getExecutionStatus(execStat);
                testCase.setExecutionStatus(execStatus);
            }
            if (cursor.getColumnIndex(COLUMN_FEATURE_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_FEATURE_ID);
                testCase.setFeatureId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_KEYWORDS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_KEYWORDS);
                String keys = cursor.getString(index);
                if (keys != null) {
                    testCase.setKeywords(Arrays.asList(convertStringToArray(keys)));
                }
            }
        }
        return testCase;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(TestCase testCase) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, testCase.getId());
        initialValues.put(COLUMN_TEST_CASE_NAME, testCase.getName());
        initialValues.put(COLUMN_TEST_PROJECT_ID, testCase.getTestProjectId());
        initialValues.put(COLUMN_TEST_SUITE_ID, testCase.getTestSuiteId());
        initialValues.put(COLUMN_AUTHOR_LOGIN, testCase.getAuthorLogin());
        initialValues.put(COLUMN_SUMMARY, testCase.getSummary());
        initialValues.put(COLUMN_PRECONDITIONS, testCase.getPreconditions());
        initialValues.put(COLUMN_TEST_CASE_STATUS, testCase.getTestCaseStatus() == null ? null : testCase.getTestCaseStatus().toString());
        initialValues.put(COLUMN_TEST_IMPORTANCE, testCase.getTestImportance() == null ? null : testCase.getTestImportance().toString());
        initialValues.put(COLUMN_EXECUTION_TYPE, testCase.getExecutionType() == null ? null : testCase.getExecutionType().toString());
        initialValues.put(COLUMN_EXECUTION_ORDER, testCase.getExecutionOrder());
        initialValues.put(COLUMN_ORDER, testCase.getOrder());
        initialValues.put(COLUMN_INTERNAL_ID, testCase.getInternalId());
        initialValues.put(COLUMN_FULL_EXTERNAL_ID, testCase.getFullExternalId());
        initialValues.put(COLUMN_CHECK_DUPLICATED_NAME, testCase.getCheckDuplicatedName());
        initialValues.put(COLUMN_ACTION_ON_DUPLATED_NAME, testCase.getActionOnDuplicatedName() == null ? null : testCase.getActionOnDuplicatedName().toString());
        initialValues.put(COLUMN_VERSION_ID, testCase.getVersionId());
        initialValues.put(COLUMN_VERSION, testCase.getVersion());
        initialValues.put(COLUMN_PARENT_ID, testCase.getParentId());
        initialValues.put(COLUMN_EXECUTION_STATUS, testCase.getExecutionStatus() == null ? null : testCase.getExecutionStatus().toString());
        initialValues.put(COLUMN_PLATFORM, testCase.getPlatform() == null ? null : testCase.getPlatform().getId());
        initialValues.put(COLUMN_FEATURE_ID, testCase.getFeatureId());
        List<String> keywords = testCase.getKeywords();
        if (keywords != null) {
            String[] keys = new String[keywords.size()];
            initialValues.put(COLUMN_KEYWORDS, convertArrayToString(keywords.toArray(keys)));
        }
        initialValues.put(COLUMN_TEST_PLAN_ID, testCase.getTestPlanId());
    }

    @Override
    public TestCase fetchTestCaseById(int testCaseId) {
        final String selectionArgs[] = {String.valueOf(testCaseId)};
        final String selection = COLUMN_ID + " = ?";
        TestCase testCase = new TestCase(testCaseId);
        cursor = super.query(ITestCaseSchema.TESTCASE_TABLE, ITestCaseSchema.TESTCASE_COLUMNS, selection,
                selectionArgs, ITestCaseSchema.COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                testCase = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
            // READ TEST STEPS
            List<TestCaseStep> testCaseSteps = testCaseStepDao.fetchAllTestCaseStepsByTestCaseId(testCaseId);
            testCase.setSteps(testCaseSteps);
            List<CustomField> testCaseCustomFields = customFieldDao.fetchAllCustomFieldsByTestCaseId(testCaseId);
            testCase.setCustomFields(testCaseCustomFields);
            Platform testCasePlatform = platformDao.fetchPlatformByPlatformId(testCase.getPlatform().getId());
            testCase.setPlatform(testCasePlatform);
        }
        return testCase;
    }

    @Override
    public List<TestCase> fetchTestCasesByTestPlanId(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId)};
        final String selection = COLUMN_TEST_PLAN_ID + " = ?";
        cursor = super.query(ITestCaseSchema.TESTCASE_TABLE, ITestCaseSchema.TESTCASE_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        List<TestCase> testCases = new ArrayList<TestCase>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                TestCase testCase = cursorToEntity(cursor);
                // READ TEST STEPS
                List<TestCaseStep> testCaseSteps = testCaseStepDao.fetchAllTestCaseStepsByTestCaseId(testCase.getId());
                testCase.setSteps(testCaseSteps);
                List<CustomField> testCaseCustomFields = customFieldDao.fetchAllCustomFieldsByTestCaseId(testCase.getId());
                testCase.setCustomFields(testCaseCustomFields);
                Platform testCasePlatform = platformDao.fetchPlatformByPlatformId(testCase.getPlatform().getId());
                testCase.setPlatform(testCasePlatform);
                testCases.add(testCase);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return testCases;
    }

    @Override
    public boolean addTestCase(TestCase testCase, Integer testPlanId) {
        boolean result = false;
        // set values
        try {
            setContentValue(testCase);
            result = (super.insert(TESTCASE_TABLE, getContentValue()) > 0);
            if (result) {
                if (testCase.getSteps() != null && !testCaseStepDao.addTestCaseSteps(testCase.getSteps(), testCase.getId())) {
                    result = false;
                }
                if (testCase.getCustomFields() != null && !customFieldDao.addCustomFields(testCase.getCustomFields(), testCase.getId())) {
                    result = false;
                }
                if (testCase.getPlatform() != null && !platformDao.addPlatform(testCase.getPlatform())) {
                    result = false;
                }
            }
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            result = false;
        }
        return result;
    }

//    @Override
//    public boolean addTestCases(List<TestCase> testCases) {
//        boolean result = true;
//        for (TestCase testCase : testCases) {
//            if (!addTestCase(testCase)) {
//                result = false;
//            }
//        }
//        return result;
//
//    }

    /**
     * This method is a fix
     *
     * @param testCases
     * @return
     */
    @Override
    public boolean addTestCases(List<TestCase> testCases, Integer testPlanId) {
        boolean result = true;
        for (TestCase testCase : testCases) {
            testCase.setTestPlanId(testPlanId);
            if (!addTestCase(testCase, testPlanId)) {
                result = false;
            }
        }
        return result;
    }

    @Override
    public boolean updateTestCase(int testCaseId, ExecutionStatus newExecutionStatus) {
        ContentValues initialValues = new ContentValues();
        initialValues.put(COLUMN_EXECUTION_STATUS, newExecutionStatus == null ? null : newExecutionStatus.toString());
        boolean result = false;
        final String selectionArgs[] = {String.valueOf(testCaseId)};
        final String selection = COLUMN_ID + " = ?";
        // set values
        try {
            result = (super.update(TESTCASE_TABLE, initialValues, selection, selectionArgs) > 0);
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            result = false;
        }
        return result;
    }

    @Override
    public boolean deleteAllTestCases() {
        return false;
    }
}
