package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.ITestCaseStepSchema;
import uoc.testlink4android.models.TestCaseStep;
import uoc.testlink4android.testlink.constants.ExecutionType;


class TestCaseStepDao extends DbContentProvider
        implements ITestCaseStepSchema, ITestCaseStepDao {
    private Cursor cursor;
    private ContentValues initialValues;

    public TestCaseStepDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected TestCaseStep cursorToEntity(Cursor cursor) {
        TestCaseStep testCaseStep = null;
        int index = 0;
        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_ID);
                testCaseStep = new TestCaseStep(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_TEST_CASE_VERSION_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TEST_CASE_VERSION_ID);
                testCaseStep.setTestCaseVersionId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_NUMBER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_NUMBER);
                testCaseStep.setNumber(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_ACTIONS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ACTIONS);
                testCaseStep.setActions(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_EXPECTED_RESULTS) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXPECTED_RESULTS);
                testCaseStep.setExpectedResults(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_ACTIVE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_ACTIVE);
                testCaseStep.setActive(cursor.getInt(index) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_NUMBER) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_NUMBER);
                testCaseStep.setNumber(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_EXECUTION_TYPE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_EXECUTION_TYPE);
                ExecutionType executionType = ExecutionType.getExecutionType(cursor.getInt(index));
                testCaseStep.setExecutionType(executionType);
            }
        }
        return testCaseStep;
    }

    @Override
    public TestCaseStep fetchTestCaseStepById(int testCaseStepId) {
        final String selectionArgs[] = {String.valueOf(testCaseStepId)};
        final String selection = COLUMN_TEST_CASE_ID + " = ?";
        TestCaseStep testCase = new TestCaseStep(testCaseStepId);
        cursor = super.query(ITestCaseStepSchema.TESTCASESTEP_TABLE, ITestCaseStepSchema.TESTCASESTEP_COLUMNS, selection,
                selectionArgs, ITestCaseStepSchema.COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                testCase = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return testCase;
    }

    @Override
    public boolean addTestCaseSteps(List<TestCaseStep> testCaseSteps, int testCaseId) {
        boolean result = true;
        for (TestCaseStep testCaseStep : testCaseSteps) {
            if (!addTestCaseStep(testCaseStep, testCaseId)) {
                result = false;
            }
        }
        return result;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(TestCaseStep testCaseStep, int testTestCaseId) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, testCaseStep.getId());
        initialValues.put(COLUMN_TEST_CASE_VERSION_ID, testCaseStep.getTestCaseVersionId());
        initialValues.put(COLUMN_NUMBER, testCaseStep.getNumber());
        initialValues.put(COLUMN_ACTIONS, testCaseStep.getActions());
        initialValues.put(COLUMN_EXPECTED_RESULTS, testCaseStep.getExpectedResults());
        initialValues.put(COLUMN_EXECUTION_TYPE, testCaseStep.getExecutionType().getValue());
        initialValues.put(COLUMN_TEST_CASE_ID, testTestCaseId);
    }


    @Override
    public List<TestCaseStep> fetchAllTestCaseStepsByTestCaseId(int testCaseId) {
        final String selectionArgs[] = {String.valueOf(testCaseId)};
        final String selection = COLUMN_TEST_CASE_ID + " = ?";
        cursor = super.query(TESTCASESTEP_TABLE, TESTCASESTEP_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        List<TestCaseStep> testCaseSteps = new ArrayList<TestCaseStep>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                TestCaseStep testCaseStep = cursorToEntity(cursor);
                testCaseSteps.add(testCaseStep);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return testCaseSteps;
    }

    @Override
    public boolean addTestCaseStep(TestCaseStep testCaseSteps, int testCaseId) {
        // set values
        setContentValue(testCaseSteps, testCaseId);
        try {
            return super.insert(TESTCASESTEP_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    @Override
    public boolean deleteAllTestCaseSteps() {
        return false;
    }
}
