package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.DatabaseUtils;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.text.TextUtils;
import android.util.Log;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.ITestPlanSchema;
import uoc.testlink4android.models.TestPlan;

import static uoc.testlink4android.db.schemas.ITestCaseSchema.COLUMN_EXECUTION_STATUS;
import static uoc.testlink4android.db.schemas.ITestCaseSchema.COLUMN_TEST_PLAN_ID;
import static uoc.testlink4android.db.schemas.ITestCaseSchema.TESTCASE_TABLE;


public class TestPlanDao extends DbContentProvider
        implements ITestPlanSchema, ITestPlanDao {

    private Cursor cursor;
    private ContentValues initialValues;

    public TestPlanDao(SQLiteDatabase db) {
        super(db);
    }

    protected TestPlan cursorToEntity(Cursor cursor) {
        TestPlan testplan = null;

        int index;

        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(COLUMN_ID);
                testplan = new TestPlan(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_PROJECT_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_PROJECT_NAME);
                testplan.setProjectName(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_TESTPLAN_NAME) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_TESTPLAN_NAME);
                testplan.setName(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_PROJECT_ID) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_PROJECT_ID);
                testplan.setProjectId(cursor.getInt(index));
            }
            if (cursor.getColumnIndex(COLUMN_NOTES) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_NOTES);
                testplan.setNotes(cursor.getString(index));
            }
            if (cursor.getColumnIndex(COLUMN_IS_ACTIVE) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_IS_ACTIVE);
                testplan.setActive(cursor.getInt(index) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_IS_PUBLIC) != -1) {
                index = cursor.getColumnIndexOrThrow(
                        COLUMN_IS_PUBLIC);
                testplan.setPublic(cursor.getInt(index) > 0);
            }
        }
        return testplan;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(TestPlan testPlan) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, testPlan.getId());
        initialValues.put(COLUMN_PROJECT_NAME, testPlan.getProjectName());
        initialValues.put(COLUMN_PROJECT_ID, testPlan.getProjectId());
        initialValues.put(COLUMN_TESTPLAN_NAME, testPlan.getName());
        initialValues.put(COLUMN_NOTES, testPlan.getNotes());
        initialValues.put(COLUMN_IS_ACTIVE, testPlan.isActive());
        initialValues.put(COLUMN_IS_PUBLIC, testPlan.isPublic());
    }

    @Override
    public long testPlanSize(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId)};
        final String selection = COLUMN_TEST_PLAN_ID + " = ?";
        return DatabaseUtils.queryNumEntries(mDb, TESTCASE_TABLE,
                selection, selectionArgs);
    }

    @Override
    public long executedTests(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId)};
        final String selection = COLUMN_TEST_PLAN_ID + " = ?";
        return DatabaseUtils.queryNumEntries(mDb, TESTCASE_TABLE,
                selection, selectionArgs);
    }

    @Override
    public long passedTests(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId), "p"};
        final String selection = COLUMN_TEST_PLAN_ID + " = ? AND " + COLUMN_EXECUTION_STATUS + " = ?";
        return DatabaseUtils.queryNumEntries(mDb, TESTCASE_TABLE,
                selection, selectionArgs);
    }

    @Override
    public long failedTests(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId), "f"};
        final String selection = COLUMN_TEST_PLAN_ID + " = ? AND " + COLUMN_EXECUTION_STATUS + " = ?";
        return DatabaseUtils.queryNumEntries(mDb, TESTCASE_TABLE,
                selection, selectionArgs);
    }
//    final String selectionArgs[] = {String.valueOf(testCaseId)};
//    final String selection = " = ?";
//    TestCase testCase = new TestCase(testCaseId);
//    cursor = super.query(ITestCaseSchema.TESTCASE_TABLE, ITestCaseSchema.TESTCASE_COLUMNS, selection,
//                         selectionArgs, ITestCaseSchema.COLUMN_ID);

    @Override
    public TestPlan fetchTestPlanById(int testPlanId) {
        final String selectionArgs[] = {String.valueOf(testPlanId)};
        final String selection = COLUMN_ID + " = ?";
//        TestPlan result = new TestPlan(testPlanId);
        TestPlan result = null;
        cursor = super.query(TESTPLAN_TABLE, TESTPLAN_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                result = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return result;
    }

    @Override
    public List<TestPlan> fetchTestPlansByProjectId(String[] projectIdList) {
        String selection = new String(COLUMN_PROJECT_ID + " IN (" +
                TextUtils.join(",", Collections.nCopies(projectIdList.length, "?")) + " ) ");
        List<TestPlan> testPlans = null;
        if (projectIdList.length > 0) {
            cursor = super.query(TESTPLAN_TABLE, TESTPLAN_COLUMNS, selection,
                    projectIdList, COLUMN_ID);

            testPlans = new ArrayList<TestPlan>(cursor.getCount());
            if (cursor != null) {
                cursor.moveToFirst();
                while (!cursor.isAfterLast()) {
                    TestPlan testPlan = cursorToEntity(cursor);
                    testPlans.add(testPlan);
                    cursor.moveToNext();
                }
                cursor.close();
            }
        } else {
            testPlans = new ArrayList<TestPlan>(0);
        }
        return testPlans;
    }

    @Override
    public List<TestPlan> fetchTestPlansByProjectId(Integer projectId) {
        final String selectionArgs[] = {String.valueOf(projectId)};
        final String selection = COLUMN_PROJECT_ID + " = ?";
        List<TestPlan> testPlans = null;
        cursor = super.query(TESTPLAN_TABLE, TESTPLAN_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        testPlans = new ArrayList<TestPlan>(cursor.getCount());
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                TestPlan testPlan = cursorToEntity(cursor);
                testPlans.add(testPlan);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return testPlans;
    }

    @Override
    public List<TestPlan> fetchAllTestPlans() {
        List<TestPlan> testPlans = new ArrayList<TestPlan>();
        cursor = super.query(TESTPLAN_TABLE, TESTPLAN_COLUMNS, null,
                null, COLUMN_ID);

        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                TestPlan testPlan = cursorToEntity(cursor);
                testPlans.add(testPlan);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return testPlans;
    }

    @Override
    public boolean addTestPlan(TestPlan testPlan) {
        // set values
        setContentValue(testPlan);
        try {
            return super.insert(TESTPLAN_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    @Override
    public boolean addTestPlans(List<TestPlan> testPlans) {
        // set values
        try {
            for (TestPlan testPlan : testPlans) {
                setContentValue(testPlan);
                if (!(super.insert(TESTPLAN_TABLE, getContentValue()) > 0)) {
                    return false;
                }
            }
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
        return true;
    }

    @Override
    public boolean deleteAllTestPlans() {
        return false;
    }
}