package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.ITestProjectSchema;
import uoc.testlink4android.models.TestProject;

public class TestProjectDao extends DbContentProvider implements ITestProjectSchema, ITestProjectDao {
    private ContentValues initialValues;
    private Cursor cursor;

    public TestProjectDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    protected TestProject cursorToEntity(Cursor cursor) {
        TestProject testProject = null;

        int idIndex;
        int projectNameIndex;
        int prefix;
        int notes;
        int enableRequirements;
        int enableInventory;
        int enableAutomation;
        int enableTestPriority;
        int isActive;
        int isPublic;

        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                idIndex = cursor.getColumnIndexOrThrow(COLUMN_ID);
                testProject = new TestProject(cursor.getInt(idIndex));
            }
            if (cursor.getColumnIndex(COLUMN_NAME) != -1) {
                projectNameIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_NAME);
                testProject.setName(cursor.getString(projectNameIndex));
            }
            if (cursor.getColumnIndex(COLUMN_PREFIX) != -1) {
                prefix = cursor.getColumnIndexOrThrow(
                        COLUMN_PREFIX);
                testProject.setPrefix(cursor.getString(prefix));
            }
            if (cursor.getColumnIndex(COLUMN_NOTES) != -1) {
                notes = cursor.getColumnIndexOrThrow(
                        COLUMN_NOTES);
                testProject.setNotes(cursor.getString(notes));
            }
            if (cursor.getColumnIndex(COLUMN_COLOR) != -1) {
                notes = cursor.getColumnIndexOrThrow(
                        COLUMN_COLOR);
                testProject.setColor(cursor.getInt(notes));
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_REQUIREMENTS) != -1) {
                enableRequirements = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_REQUIREMENTS);
                testProject.setEnableRequirements(cursor.getInt(enableRequirements) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_INVENTORY) != -1) {
                enableInventory = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_INVENTORY);
                testProject.setEnableInventory(cursor.getInt(enableInventory) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_AUTOMATION) != -1) {
                enableAutomation = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_AUTOMATION);
                testProject.setEnableAutomation(cursor.getInt(enableAutomation) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_ENABLE_TEST_PRIORITY) != -1) {
                enableTestPriority = cursor.getColumnIndexOrThrow(
                        COLUMN_ENABLE_TEST_PRIORITY);
                testProject.setEnableTestPriority(cursor.getInt(enableTestPriority) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_IS_ACTIVE) != -1) {
                isActive = cursor.getColumnIndexOrThrow(
                        COLUMN_IS_ACTIVE);
                testProject.setActive(cursor.getInt(isActive) > 0);
            }
            if (cursor.getColumnIndex(COLUMN_IS_PUBLIC) != -1) {
                isPublic = cursor.getColumnIndexOrThrow(
                        COLUMN_IS_PUBLIC);
                testProject.setPublic(cursor.getInt(isPublic) > 0);
            }
        }
        return testProject;
    }

    @Override
    public TestProject fetchTestProjectById(int testProjectId) {
        final String selectionArgs[] = {String.valueOf(testProjectId)};
        final String selection = COLUMN_ID + " = ?";
//        TestProject result = new TestProject(testProjectId);
        TestProject result = null;
        cursor = super.query(TESTPROJECT_TABLE, TESTPROJECT_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                result = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }
        return result;
    }

    @Override
    public List<TestProject> fetchAllTestProjects() {
        List<TestProject> testProjects = new ArrayList<TestProject>();
        cursor = super.query(TESTPROJECT_TABLE, TESTPROJECT_COLUMNS, null,
                null, COLUMN_ID);

        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                TestProject testProject = cursorToEntity(cursor);
                testProjects.add(testProject);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return testProjects;
    }

    @Override
    public boolean addTestProject(TestProject testProjects) {
        // set values
        setContentValue(testProjects);
        try {
            return super.insert(TESTPROJECT_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    @Override
    public boolean addTestProjects(List<TestProject> testProjects) {
        // set values
        try {
            for (TestProject testPlan : testProjects) {
                setContentValue(testPlan);
                if (!(super.insert(TESTPROJECT_TABLE, getContentValue()) > 0)) {
                    return false;
                }
            }
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
        return true;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(TestProject testProject) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, testProject.getId());
        initialValues.put(COLUMN_NAME, testProject.getName());
        initialValues.put(COLUMN_PREFIX, testProject.getPrefix());
        initialValues.put(COLUMN_NOTES, testProject.getNotes());
        initialValues.put(COLUMN_COLOR, testProject.getColor());
        initialValues.put(COLUMN_ENABLE_REQUIREMENTS, testProject.isEnableRequirements());
        initialValues.put(COLUMN_ENABLE_INVENTORY, testProject.isEnableInventory());
        initialValues.put(COLUMN_ENABLE_AUTOMATION, testProject.isEnableAutomation());
        initialValues.put(COLUMN_ENABLE_TEST_PRIORITY, testProject.isEnableTestPriority());
        initialValues.put(COLUMN_IS_ACTIVE, testProject.isActive());
        initialValues.put(COLUMN_IS_PUBLIC, testProject.isPublic());

    }

    @Override
    public boolean deleteAllTestProjects() {
        final String selectionArgs[] = {};
        final String selection = COLUMN_ID + " = ?";
        return super.delete(TESTPROJECT_TABLE, null, null) > 0;
    }
}
