package uoc.testlink4android.db.daos;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteConstraintException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

import uoc.testlink4android.db.DbContentProvider;
import uoc.testlink4android.db.schemas.IUserSchema;
import uoc.testlink4android.models.User;

public class UserDao extends DbContentProvider
        implements IUserSchema, IUserDao {

    private Cursor cursor;
    private ContentValues initialValues;

    public UserDao(SQLiteDatabase db) {
        super(db);
    }

    @Override
    public uoc.testlink4android.models.User fetchUserById(int userId) {
        return null;
    }

    @Override
    public boolean addUsers(List<uoc.testlink4android.models.User> users) {
        return false;
    }

    @Override
    public boolean deleteAllUsers() {
        return false;
    }

    public User fetchUserByID(int id) {
        final String selectionArgs[] = {String.valueOf(id)};
        final String selection = " = ?";
        User user = new User(id);
        cursor = super.query(USER_TABLE, USER_COLUMNS, selection,
                selectionArgs, COLUMN_ID);
        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                user = cursorToEntity(cursor);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return user;
    }

    public List<User> fetchAllUsers() {
        List<User> userList = new ArrayList<User>();
        cursor = super.query(USER_TABLE, USER_COLUMNS, null,
                null, COLUMN_ID);

        if (cursor != null) {
            cursor.moveToFirst();
            while (!cursor.isAfterLast()) {
                User user = cursorToEntity(cursor);
                userList.add(user);
                cursor.moveToNext();
            }
            cursor.close();
        }

        return userList;
    }

    public boolean addUser(User user) {
        // set values
        setContentValue(user);
        try {
            return super.insert(USER_TABLE, getContentValue()) > 0;
        } catch (SQLiteConstraintException ex) {
            Log.w("Database", ex.getMessage());
            return false;
        }
    }

    protected User cursorToEntity(Cursor cursor) {

        User user = null;

        int idIndex;
        int userNameIndex;
        int emailIndex;
        int lastNameIndex;

        if (cursor != null) {
            if (cursor.getColumnIndex(COLUMN_ID) != -1) {
                idIndex = cursor.getColumnIndexOrThrow(COLUMN_ID);
                user.setDbID(cursor.getInt(idIndex));
                user = new User(idIndex);
            }
            if (cursor.getColumnIndex(COLUMN_USER_NAME) != -1) {
                userNameIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_USER_NAME);
                user.setFirstName(cursor.getString(userNameIndex));
            }
            if (cursor.getColumnIndex(COLUMN_LAST_NAME) != -1) {
                lastNameIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_LAST_NAME);
                user.setLastName(cursor.getString(lastNameIndex));
            }
            if (cursor.getColumnIndex(COLUMN_EMAIL) != -1) {
                emailIndex = cursor.getColumnIndexOrThrow(
                        COLUMN_EMAIL);
                user.setEmailAddress(cursor.getString(emailIndex));
            }
        }
        return user;
    }

    private ContentValues getContentValue() {
        return initialValues;
    }

    private void setContentValue(User user) {
        initialValues = new ContentValues();
        initialValues.put(COLUMN_ID, user.getDbID());
        initialValues.put(COLUMN_USER_NAME, user.getFirstName());
        initialValues.put(COLUMN_LAST_NAME, user.getLastName());
        initialValues.put(COLUMN_EMAIL, user.getEmailAddress());
    }

}
