/*
 * The MIT License
 *
 * Copyright (c) 2010 Bruno P. Kinoshita http://www.kinoshita.eti.br
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package uoc.testlink4android.models;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Bruno P. Kinoshita - http://www.kinoshita.eti.br
 * @since 1.9.0-1
 */
public class TestPlan implements Serializable {

    private static final long serialVersionUID = -758553487485596180L;

    private Integer id;
    private String name;
    private String projectName;
    private Integer projectId;
    private String notes;
    private Boolean isActive;
    private Boolean isPublic;
    private List<CustomField> customFields;

    /**
     *
     */
    public TestPlan() {
        super();
        this.customFields = new ArrayList<CustomField>();
    }

    public TestPlan(Integer id) {
        super();
        this.id = id;
    }

    /**
     * @param id          ID
     * @param name        name
     * @param projectName project name
     * @param notes       notes
     * @param isActive    is active flag
     * @param isPublic    is public flag
     */
    public TestPlan(Integer id, String name, String projectName, String notes, Boolean isActive, Boolean isPublic) {
        this(id, name, projectName, notes, isActive, isPublic, new ArrayList<CustomField>());
    }

    /**
     * @param id           ID
     * @param name         name
     * @param projectName  project name
     * @param projectId    project id
     * @param notes        notes
     * @param isActive     is active flag
     * @param isPublic     is public flag
     * @param customFields custom fields
     */
    public TestPlan(Integer id, String name, String projectName, Integer projectId, String notes, Boolean isActive, Boolean isPublic,
                    List<CustomField> customFields) {
        super();
        this.id = id;
        this.name = name;
        this.projectName = projectName;
        this.projectId = projectId;
        this.notes = notes;
        this.isActive = isActive;
        this.isPublic = isPublic;
        this.customFields = customFields;
    }

    public TestPlan(Integer id, String name, String projectName, String notes, Boolean isActive, Boolean isPublic,
                    List<CustomField> customFields) {
        this(id, name, projectName, null, notes, isActive, isPublic, customFields);
    }

    public Integer getProjectId() {
        return projectId;
    }

    public void setProjectId(Integer projectId) {
        this.projectId = projectId;
    }

    /**
     * @return the id
     */
    public Integer getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return the projectName
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * @param projectName the projectName to set
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * @return the notes
     */
    public String getNotes() {
        return notes;
    }

    /**
     * @param notes the notes to set
     */
    public void setNotes(String notes) {
        this.notes = notes;
    }

    /**
     * @return the isActive
     */
    public Boolean isActive() {
        return isActive;
    }

    /**
     * @param isActive the isActive to set
     */
    public void setActive(Boolean isActive) {
        this.isActive = isActive;
    }

    /**
     * @return the isPublic
     */
    public Boolean isPublic() {
        return isPublic;
    }

    /**
     * @param isPublic the isPublic to set
     */
    public void setPublic(Boolean isPublic) {
        this.isPublic = isPublic;
    }

    public List<CustomField> getCustomFields() {
        return customFields;
    }

    public void setCustomFields(List<CustomField> customFields) {
        this.customFields = customFields;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "TestPlan [id=" + id + ", name=" + name + ", projectName=" + projectName + ", notes=" + notes
                + ", isActive=" + isActive + ", isPublic=" + isPublic + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        TestPlan testPlan = (TestPlan) o;

        if (id != null ? !id.equals(testPlan.id) : testPlan.id != null) return false;
        if (name != null ? !name.equals(testPlan.name) : testPlan.name != null) return false;
        if (projectName != null ? !projectName.equals(testPlan.projectName) : testPlan.projectName != null)
            return false;
        if (projectId != null ? !projectId.equals(testPlan.projectId) : testPlan.projectId != null)
            return false;
        if (notes != null ? !notes.equals(testPlan.notes) : testPlan.notes != null) return false;
        if (isActive != null ? !isActive.equals(testPlan.isActive) : testPlan.isActive != null)
            return false;
        if (isPublic != null ? !isPublic.equals(testPlan.isPublic) : testPlan.isPublic != null)
            return false;
        return customFields != null ? customFields.equals(testPlan.customFields) : testPlan.customFields == null;

    }
}
