package uoc.testlink4android.ui;

import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.text.Html;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewManager;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import uoc.testlink4android.R;
import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.Execution;
import uoc.testlink4android.models.TestCase;
import uoc.testlink4android.models.TestCaseStep;
import uoc.testlink4android.testlink.constants.ExecutionStatus;
import uoc.testlink4android.testlink.constants.ExecutionType;
import uoc.testlink4android.util.Constantes;

public class TestCaseActivity extends AppCompatActivity {

    /**
     * The {@link android.support.v4.view.PagerAdapter} that will provide
     * fragments for each of the sections. We use a
     * {@link FragmentPagerAdapter} derivative, which will keep every
     * loaded fragment in memory. If this becomes too memory intensive, it
     * may be best to switch to a
     * {@link android.support.v4.app.FragmentStatePagerAdapter}.
     */
    private SectionsPagerAdapter mSectionsPagerAdapter;

    /**
     * The {@link ViewPager} that will host the section contents.
     */
    private ViewPager mViewPager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_test_case_view);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        // Create the adapter that will return a fragment for each of the three
        // primary sections of the activity.
        mSectionsPagerAdapter = new SectionsPagerAdapter(getSupportFragmentManager());

        // Set up the ViewPager with the sections adapter.
        mViewPager = (ViewPager) findViewById(R.id.container);
        mViewPager.setAdapter(mSectionsPagerAdapter);

        boolean visualizationOnly = getIntent().getBooleanExtra(Constantes.TEST_PLAN_VISUALIZATION_ONLY, false);
        FloatingActionButton fab = (FloatingActionButton) findViewById(R.id.failed);
        FloatingActionButton pass = (FloatingActionButton) findViewById(R.id.passed);

        if (visualizationOnly) {
            ((ViewManager) pass.getParent()).removeView(pass);
            ((ViewManager) fab.getParent()).removeView(fab);
        } else {
            fab.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    int position = mViewPager.getCurrentItem();
                    TestCase testCase = mSectionsPagerAdapter.getTestCaseList(position);
                    Fragment frag = mSectionsPagerAdapter.getItem(position);

                    Execution executionResult = new Execution(testCase.getId());
                    executionResult.setBuildId(getIntent().getIntExtra(Constantes.BUILD_ID, 0));
                    executionResult.setTestCaseId(testCase.getId());
                    executionResult.setTesterId(0);
                    executionResult.setExecutionType(ExecutionType.MANUAL);
                    executionResult.setTestPlanId(getIntent().getIntExtra(Constantes.TEST_PLAN_ID, 0));
                    executionResult.setTestCaseVersionNumber(testCase.getVersion());
                    executionResult.setExecutionTimeStamp(new Date(System.currentTimeMillis()));
                    executionResult.setStatus(ExecutionStatus.FAILED);
                    testCase.setExecutionStatus(ExecutionStatus.FAILED);
                    TextView testStatus = (TextView) frag.getView().findViewById(R.id.test_status);
                    GradientDrawable buttonWithBorder = (GradientDrawable) getResources().getDrawable(R.drawable.rounded_button_border, null);
                    buttonWithBorder = (GradientDrawable) buttonWithBorder.mutate();
                    buttonWithBorder.setStroke(4, Color.RED);
                    testStatus.setText(ExecutionStatus.FAILED.name());
                    testStatus.setTextColor(Color.RED);
                    testStatus.setBackground(buttonWithBorder);
                    testStatus.refreshDrawableState();
                    Database.getInstance(getApplicationContext()).mTestCaseDao.updateTestCase(testCase.getId(), ExecutionStatus.FAILED);
                    Database.getInstance(getApplicationContext()).mExecutionDao.addExecution(executionResult, testCase.getId());
//                    Snackbar.make(view, "Replace with your own action "+testCase, Snackbar.LENGTH_LONG)
//                            .setAction("Action", null).show();
//                    recreate();
                }
            });

            pass.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    int position = mViewPager.getCurrentItem();
                    TestCase testCase = mSectionsPagerAdapter.getTestCaseList(position);
                    Fragment frag = mSectionsPagerAdapter.getItem(position);

                    Execution executionResult = new Execution(testCase.getId());
                    executionResult.setBuildId(getIntent().getIntExtra(Constantes.BUILD_ID, 0));
                    executionResult.setTestCaseId(testCase.getId());
                    executionResult.setTesterId(0);
                    executionResult.setExecutionType(ExecutionType.MANUAL);
                    executionResult.setTestPlanId(getIntent().getIntExtra(Constantes.TEST_PLAN_ID, 0));
                    executionResult.setTestCaseVersionNumber(testCase.getVersion());
                    executionResult.setExecutionTimeStamp(new Date(System.currentTimeMillis()));
                    executionResult.setStatus(ExecutionStatus.PASSED);
                    testCase.setExecutionStatus(ExecutionStatus.PASSED);
                    TextView testStatus = (TextView) frag.getView().findViewById(R.id.test_status);

                    testStatus.setText(ExecutionStatus.PASSED.name());

                    GradientDrawable buttonWithBorder = (GradientDrawable) getResources().getDrawable(R.drawable.rounded_button_border, null);
                    buttonWithBorder = (GradientDrawable) buttonWithBorder.mutate();
                    buttonWithBorder.setStroke(4, Color.GREEN);
                    testStatus.setText(ExecutionStatus.PASSED.name());
                    testStatus.setTextColor(Color.GREEN);
                    testStatus.setBackground(buttonWithBorder);
                    testStatus.refreshDrawableState();
                    Database.getInstance(getApplicationContext()).mTestCaseDao.updateTestCase(testCase.getId(), ExecutionStatus.PASSED);
                    Database.getInstance(getApplicationContext()).mExecutionDao.addExecution(executionResult, testCase.getId());
//                    Snackbar.make(view, "Replace with your own action "+testCase, Snackbar.LENGTH_LONG)
//                            .setAction("Action", null).show();
//                    recreate();
                }
            });
        }


        String testPlanName = getIntent().getStringExtra(Constantes.TEST_PLAN_NAME);
        setTitle(testPlanName);

    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_test_case_view, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.back_to_testplan_view) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class TestCaseView extends Fragment {
        private TestCase testCase;
        private View view;

        public TestCaseView() {
            super();
        }

        /**
         * Returns a new instance of this fragment for the given section
         * number.
         */
        public static TestCaseView newInstance(TestCase testCase) {
            TestCaseView fragment = new TestCaseView();
            fragment.setTestCase(testCase);
            return fragment;
        }

        @Override
        public void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
        }

        public void setTestCase(TestCase testCase) {
            this.testCase = testCase;
        }


        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                                 Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.fragment_test_case_view, container, false);
            TextView testName = (TextView) rootView.findViewById(R.id.test_name);
            testName.setText(testCase.getFullExternalId() + " | " + testCase.getName());

            if (testCase.getSummary() != null && !"".equals(testCase.getSummary())) {
                TextView description = (TextView) rootView.findViewById(R.id.test_description);
                StringBuilder descriptionText = new StringBuilder("<b>Testcase description:</b> <p>" + testCase.getSummary() + "<p/>");
                if (testCase.getPreconditions() != null && !"".equals(testCase.getPreconditions())) {
                    descriptionText.append("<b>Testcase preconditions:</b> <p>" + testCase.getPreconditions() + "<p/>");
                }
                description.setText(Html.fromHtml(descriptionText.toString(), Html.FROM_HTML_MODE_COMPACT));
            }

            if (testCase.getSteps() != null && testCase.getSteps().size() > 0) {
                TextView testSteps = (TextView) rootView.findViewById(R.id.test_steps);
                List<TestCaseStep> testCaseSteps = testCase.getSteps();
                StringBuilder testStepsText = new StringBuilder();
                int index = 1;
                for (TestCaseStep testCaseStep : testCaseSteps) {
                    testStepsText.append("<p><b><big>Step " + index + "</big> - Actions:</b> " + testCaseStep.getActions());
                    testStepsText.append("<b>Expected results:</b> " + testCaseStep.getExpectedResults() + "<p/>");
                    index++;
                }
                testSteps.setText(Html.fromHtml(testStepsText.toString(), Html.FROM_HTML_MODE_COMPACT));
            }
            TextView testStatus = (TextView) rootView.findViewById(R.id.test_status);
            GradientDrawable buttonWithBorder = (GradientDrawable) getContext().getResources().getDrawable(R.drawable.rounded_button_border, null);
            buttonWithBorder = (GradientDrawable) buttonWithBorder.mutate();
//            buttonWithBorder.setColor(project.getColor());
            testStatus.setText(testCase.getExecutionStatus().name());
            if ((testCase.getExecutionStatus() != null) && (ExecutionStatus.FAILED == testCase.getExecutionStatus())) {
                buttonWithBorder.setStroke(4, Color.RED);
                testStatus.setTextColor(Color.RED);
            } else if ((testCase.getExecutionStatus() != null) && (ExecutionStatus.PASSED == testCase.getExecutionStatus())) {
                buttonWithBorder.setStroke(4, Color.GREEN);
                testStatus.setTextColor(Color.GREEN);
            } else if ((testCase.getExecutionStatus() != null) && (ExecutionStatus.NOT_RUN == testCase.getExecutionStatus())) {
                buttonWithBorder.setStroke(4, Color.BLACK);
                testStatus.setTextColor(Color.BLACK);
            }
            testStatus.setBackground(buttonWithBorder);
            testStatus.refreshDrawableState();
            this.view = rootView;
            return rootView;
        }

        @Override
        public View getView() {
            return view;
        }
    }

    /**
     * A {@link FragmentPagerAdapter} that returns a fragment corresponding to
     * one of the sections/tabs/pages.
     */
        public class SectionsPagerAdapter extends FragmentPagerAdapter {
        List<TestCase> testCaseList = new ArrayList<>(0);
        Fragment[] testCaseFragments = new TestCaseView[0];
        private Database databaseAccess;

        public SectionsPagerAdapter(FragmentManager fm) {
            super(fm);
            this.databaseAccess = Database.getInstance(getApplicationContext());
            int testPlanId = getIntent().getIntExtra(Constantes.TEST_PLAN_ID, -1);
            this.testCaseList = this.databaseAccess.mTestCaseDao.fetchTestCasesByTestPlanId(testPlanId);
            this.testCaseFragments = new TestCaseView[testCaseList.size()];
        }

        public TestCase getTestCaseList(int position) {
            TestCase testCase = null;
            if (position < testCaseList.size()) {
                testCase = testCaseList.get(position);
            }
            return testCase;
        }

        @Override
        public Fragment getItem(int position) {
            Fragment placeholderFragment = null;
            if (position < testCaseFragments.length) {
                if (testCaseFragments[position] == null) {
                    testCaseFragments[position] = TestCaseView.newInstance(testCaseList.get(position));
                }
                placeholderFragment = testCaseFragments[position];
            }
            return placeholderFragment;
        }

        @Override
        public int getCount() {
            return testCaseList.size();
        }

        @Override
        public CharSequence getPageTitle(int position) {
            String title = "";
            if (position < testCaseList.size()) {
                title = testCaseList.get(position).getName();
            }
            return title;
        }
    }
}
