package uoc.testlink4android.ui.fragment;

import android.app.Activity;
import android.app.Fragment;
import android.content.SharedPreferences;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.StateListDrawable;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.GridLayout;
import android.widget.ToggleButton;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import uoc.testlink4android.R;
import uoc.testlink4android.background.AsyncRefreshUI;
import uoc.testlink4android.background.AsyncResponse;
import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.TestProject;

import static uoc.testlink4android.util.Constantes.SELECTED_PROJECTS;

public class ProjectFilterView extends Fragment  implements AsyncRefreshUI {
    private Database databaseAccess;
    private View rootView;

    public ProjectFilterView() {
        super();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        this.rootView = inflater.inflate(R.layout.project_filter, container, false);
        this.databaseAccess = Database.getInstance(getActivity().getApplicationContext());
        return rootView;
    }


    private void createProjectList(){
        GridLayout gridLayout = (GridLayout) getView().findViewById(R.id.projectfilterview);

        gridLayout.removeAllViews();

        List<TestProject> testProjectList = this.databaseAccess.mTestProjectDao.fetchAllTestProjects(); // Total number of tesplans

        int total = testProjectList != null ? testProjectList.size() : 0;
        gridLayout.setColumnCount(1);
        gridLayout.setRowCount(total);
        TestProject testProject = null;

        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getContext());
        Set<String> hs = prefs.getStringSet(SELECTED_PROJECTS, new HashSet<String>());
        Set<String> selectedProjects = new HashSet<String>(hs);
        boolean hasPreference = prefs.contains(SELECTED_PROJECTS);

        for (int i = 0; i < total; i++) {
            testProject = testProjectList.get(i);
            final ToggleButton cb = new ToggleButton(getContext());
            GradientDrawable buttonSelected = (GradientDrawable) getContext().getResources().getDrawable(R.drawable.rounded_toggle_button_selected, null);
            buttonSelected = (GradientDrawable) buttonSelected.mutate();
            buttonSelected.setColor(testProject.getColor());
            StateListDrawable selectedButton = (StateListDrawable) getContext().getResources().getDrawable(R.drawable.rounded_toggle_button, null);
            selectedButton.mutate();
            selectedButton.addState(new int[]{android.R.attr.state_checked}, buttonSelected);
            cb.setBackground(selectedButton);

            String buttonText = testProject.getPrefix() + "\n" + testProject.getName();
            cb.setTextOn(buttonText);
            cb.setTextOff(buttonText);
            final String sProjectId = Integer.toString(testProject.getId());
            if (hasPreference) {
                if (selectedProjects.contains(sProjectId)) {
                    cb.setChecked(true);
                } else {
                    cb.setChecked(false);
                }
            } else {
                cb.setChecked(true);
            }
            selectedProjects.add(sProjectId);
            cb.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getContext());
                    Set<String> hs = prefs.getStringSet(SELECTED_PROJECTS, new HashSet<String>());
                    Set<String> selectedProjects = new HashSet<String>(hs);
                    if (cb.isChecked()) {
                        selectedProjects.add(sProjectId);
                    } else {
                        selectedProjects.remove(sProjectId);
                    }
                    prefs.edit().remove(SELECTED_PROJECTS).commit();
                    prefs.edit().putStringSet(SELECTED_PROJECTS, selectedProjects).commit();
                }
            });


            GridLayout.LayoutParams param = new GridLayout.LayoutParams();
            param.setMargins(10, 10, 10, 10);
            param.setGravity(Gravity.CENTER);
            gridLayout.addView(cb, param);
        }
        SharedPreferences.Editor edit = prefs.edit().remove(SELECTED_PROJECTS);
        if(edit != null) edit.commit();
        prefs.edit().putStringSet(SELECTED_PROJECTS, selectedProjects).commit();
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        createProjectList();
        super.onActivityCreated(savedInstanceState);
    }

    @Override
    public void refresh() {
        createProjectList();
    }
}
