package uoc.testlink4android.ui.fragment;

import android.app.Activity;
import android.app.Fragment;
import android.content.Intent;
import android.graphics.drawable.GradientDrawable;
import android.os.Bundle;
import android.support.design.widget.Snackbar;
import android.text.Html;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TableLayout;
import android.widget.TableRow;
import android.widget.TextView;

import java.util.List;

import uoc.testlink4android.R;
import uoc.testlink4android.background.AsyncResponse;
import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.Build;
import uoc.testlink4android.models.TestPlan;
import uoc.testlink4android.ui.TestCaseActivity;
import uoc.testlink4android.util.Constantes;

public class SelectBuildView extends Fragment{
    private Activity main;
    private Database databaseAccess;
    private int testPlanId;

    public SelectBuildView() {
        super();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.build_filter, container, false);
        this.main = getActivity();
        this.databaseAccess = Database.getInstance(main.getApplicationContext());
        return rootView;
    }

    @Override
    public void onResume() {
        super.onResume();
        updateTestCounters();
    }

    private void updateTestCounters(){
        TextView testTotales = (TextView) main.findViewById(R.id.item_testplan_testtotales);
        long numTestTotales = this.databaseAccess.mTestPlanDao.testPlanSize(testPlanId);
        testTotales.setText(Long.toString(numTestTotales));
        TextView testpasados = (TextView) main.findViewById(R.id.item_testplan_testpasados);
        long passedTests = this.databaseAccess.mTestPlanDao.passedTests(testPlanId);
        testpasados.setText(Long.toString(passedTests));
        TextView testfallados = (TextView) main.findViewById(R.id.item_testplan_testfallados);
        long failedTests = this.databaseAccess.mTestPlanDao.failedTests(testPlanId);
        testfallados.setText(Long.toString(failedTests));
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        Bundle bundle = getArguments();
        this.testPlanId = bundle == null ? -1 : bundle.getInt(Constantes.TEST_PLAN_ID);
        final String testPlanName = (bundle == null) ? null : bundle.getString(Constantes.TEST_PLAN_NAME);
        final int color = bundle == null ? -1 : bundle.getInt(Constantes.PROJECT_COLOR);
        TextView summary = (TextView) main.findViewById(R.id.item_testplan_summary);
        TestPlan testplan = this.databaseAccess.mTestPlanDao.fetchTestPlanById(testPlanId);
        StringBuilder summaryText = new StringBuilder("<b>Testplan name:</b> " + testplan.getName() + "<br/>");
        summaryText.append("<b>Project:</b> " + testplan.getProjectName() + "<br/>");
        if (testplan.getNotes() != null && !"".equals(testplan.getNotes()))
            summaryText.append("<b>Notes:</b> " + testplan.getNotes() + "<br/>");
        summary.setText(Html.fromHtml(summaryText.toString(), Html.FROM_HTML_MODE_LEGACY));

        updateTestCounters();

        // RENDER TESTPLAN INFO
        Button visualizeButton = (Button) main.findViewById(R.id.item_testplan_visualizebutton);
//        Button visualizeButton =
//        visualizeButton.setBackgroundResource(R.drawable.rounded_button);
        visualizeButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View view) {
                if (testPlanId == -1) {
                    Snackbar.make(view, "The testplan is empty!", Snackbar.LENGTH_LONG)
                            .setAction("Action", null).show();
                } else {
                    Intent intent = new Intent(main, TestCaseActivity.class);
                    intent.putExtra(Constantes.TEST_PLAN_ID, testPlanId);
                    intent.putExtra(Constantes.TEST_PLAN_VISUALIZATION_ONLY, true);
                    intent.putExtra(Constantes.TEST_PLAN_NAME, testPlanName);
                    startActivity(intent);
                }
            }
        });

        GradientDrawable buttonSelected = (GradientDrawable) getContext().getResources().getDrawable(R.drawable.rounded_button, null);
        buttonSelected = (GradientDrawable) buttonSelected.mutate();
        buttonSelected.setColor(color);
        visualizeButton.setBackground(buttonSelected);

        // RENDER VIEWS
        TableLayout tableLayout = (TableLayout) main.findViewById(R.id.buildfilter_table);

        List<Build> buildList = this.databaseAccess.mBuilDao.fetchTestplanBuilds(testPlanId); // Total number of tesplans

        int total = buildList != null ? buildList.size() : 0;
        Build build = null;
        for (int i = 0; i < total; i++) {
            build = buildList.get(i);
            Button cb = new Button(getContext());
            String buttonText = build.getName();
            final int buttonId = build.getId();
            cb.setText(buttonText);
//            cb.setBackgroundResource(R.drawable.rounded_button);
            cb.setBackground(buttonSelected);
            TableRow.LayoutParams param = new TableRow.LayoutParams();
            param.setMargins(10, 10, 10, 10);
            TableRow row = new TableRow(getActivity());
            row.setGravity(Gravity.CENTER);
            row.addView(cb, param);
            tableLayout.addView(row);

            cb.setOnClickListener(new View.OnClickListener() {
                public void onClick(View view) {
                    if (testPlanId == -1) {
                        Snackbar.make(view, "The testplan is empty!", Snackbar.LENGTH_LONG)
                                .setAction("Action", null).show();
                    } else {
                        Intent intent = new Intent(main, TestCaseActivity.class);
                        intent.putExtra(Constantes.TEST_PLAN_ID, testPlanId);
                        intent.putExtra(Constantes.TEST_PLAN_NAME, testPlanName);
                        intent.putExtra(Constantes.BUILD_ID, buttonId);
                        startActivity(intent);
                    }
                }
            });

        }
        super.onActivityCreated(savedInstanceState);
    }
}
