package uoc.testlink4android.ui.fragment;

import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentManager;
import android.app.FragmentTransaction;
import android.content.SharedPreferences;
import android.graphics.drawable.GradientDrawable;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.design.widget.Snackbar;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.GridLayout;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import uoc.testlink4android.R;
import uoc.testlink4android.background.AsyncRefreshUI;
import uoc.testlink4android.background.AsyncResponse;
import uoc.testlink4android.db.Database;
import uoc.testlink4android.models.TestPlan;
import uoc.testlink4android.models.TestProject;
import uoc.testlink4android.util.Constantes;

public class TestPlanList extends Fragment implements AsyncRefreshUI {

    private Database databaseAccess;
    private View rootView;

    public TestPlanList() {
        super();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        this.rootView = inflater.inflate(R.layout.testplan_list, container, false);
        createTesPlanList();
        return rootView;
    }

    public void createTesPlanList(){
        GridLayout gridLayout = (GridLayout) rootView.findViewById(R.id.testplanview);

        gridLayout.removeAllViews();

        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getContext());
        Set<String> selectedProjects = prefs.getStringSet(Constantes.SELECTED_PROJECTS, new HashSet<String>());
        List<TestPlan> testPlanList = null;

        if (selectedProjects.size() > 0) {
            String[] projectIdArray = new String[selectedProjects != null ? selectedProjects.size() : 0];
            testPlanList = databaseAccess.mTestPlanDao.fetchTestPlansByProjectId(selectedProjects.toArray(projectIdArray));
            int total = testPlanList != null ? testPlanList.size() : 0;
            int column = 2;
            int row = total / column;
            gridLayout.setColumnCount(column);
            gridLayout.setRowCount(row + 1);

            for (int i = 0, c = 0, r = 0; i < total; i++, c++) {
                if (c == column) {
                    c = 0;
                    r++;
                }

                Button btn = new Button(getContext());

                final TestPlan testPlan = testPlanList.get(i);
                final TestProject project = databaseAccess.mTestProjectDao.fetchTestProjectById(testPlan.getProjectId());

                btn.setText(testPlan.getName());
                btn.setId(testPlan.getId()); // Added for testing purposes (to be located from junits)
                final long testPlanTestCases = databaseAccess.mTestPlanDao.testPlanSize(testPlan.getId());
                btn.setOnClickListener(new View.OnClickListener() {
                    public void onClick(View view) {
                        if (testPlanTestCases == 0) {
                            Snackbar.make(view, "The testplan is empty!", Snackbar.LENGTH_LONG)
                                    .setAction("Action", null).show();
                        } else {
                            Bundle fragmentParameters = new Bundle();
                            fragmentParameters.putInt(Constantes.TEST_PLAN_ID, testPlan.getId());
                            fragmentParameters.putString(Constantes.TEST_PLAN_NAME, testPlan.getName());
                            fragmentParameters.putInt(Constantes.PROJECT_COLOR, project.getColor());

                            Fragment buildViewFragment = new SelectBuildView();
                            buildViewFragment.setArguments(fragmentParameters);

                            Fragment testPlanListFragment = getFragmentManager().findFragmentByTag(Constantes.FRAGMENT.TEST_PLAN_FRAGMENT.name());
                            FragmentTransaction ft = getFragmentManager().beginTransaction();
                            ft.detach(testPlanListFragment);
                            ft.add(R.id.main_content, buildViewFragment,Constantes.FRAGMENT.SELECTBUILD_FRAGMENT.name());
                            ft.commit();
                        }
                    }
                });
                btn.setSingleLine(false);
                GridLayout.LayoutParams param = new GridLayout.LayoutParams();
                param.width = 0;
                param.height = GridLayout.LayoutParams.WRAP_CONTENT;
                param.setMargins(10, 10, 10, 10);
                param.setGravity(Gravity.CENTER);
                param.columnSpec = GridLayout.spec(c, 1f);
                param.rowSpec = GridLayout.spec(r, 1f);
                btn.setLayoutParams(param);
                btn.setSingleLine(false);
                btn.setMaxHeight(200);

                GradientDrawable buttonSelected = (GradientDrawable) getContext().getResources().getDrawable(R.drawable.rounded_button, null);
                buttonSelected = (GradientDrawable) buttonSelected.mutate();
                buttonSelected.setColor(project.getColor());
                btn.setBackground(buttonSelected);

                gridLayout.addView(btn, param);
            }
        }
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.databaseAccess = Database.getInstance(getActivity().getApplicationContext());
    }

    @Override
    public void refresh() {
        createTesPlanList();
    }
}
